@@ -2,6 +2,7 @@
 # -*- coding: utf-8 -*-
 #QuizzyNator by Marian Klühspies
 
+
 #Importe
 import sys
 import time
@@ -227,30 +228,27 @@ class MainWindow(QtGui.QMainWindow):
         self.ui.antwort_4.show()
         self.ui.nextquest.hide()
 #Auslesen von fragenkatalog.py + Randomfragen + Shuffle Buttoninhalte
-        question = random.choice(fragenkatalog.questions)
-        self.ui.textfrage.setText(question.question)
-        self.antwort1=question.answer
-        self.antwort2=question.answer2
-        self.antwort3=question.answer3
-        self.antwort4=question.answer4
-        self.antwort1=unicode(self.antwort1, "utf-8")
-        self.antwort2=unicode(self.antwort2, "utf-8")
-        self.antwort3=unicode(self.antwort3, "utf-8")
-        self.antwort4=unicode(self.antwort4, "utf-8")
+        self.question = random.choice(fragenkatalog.questions)
+        self.ui.textfrage.setText(self.question.question)
+        self.antwort1=self.question.answer.decode("utf-8")
+        self.antwort2=self.question.answer2.decode("utf-8")
+        self.antwort3=self.question.answer3.decode("utf-8")
+        self.antwort4=self.question.answer4.decode("utf-8")
+
         l=[self.antwort1,self.antwort2,self.antwort3,self.antwort4]
         random.shuffle(l)
+		
         self.ui.antwort_1.setText(l[0])
         self.ui.antwort_2.setText(l[1])
         self.ui.antwort_3.setText(l[2])
         self.ui.antwort_4.setText(l[3])
-        self.richtigeantwort=unicode(self.antwort1)
-       
-#Buttonabfrage: Stimmt der Inhalt des Buttons mit dem Inhalt "Richtige Antwort" überein?
-    def antwort_1(self):
-        antwort=self.ui.antwort_1.text()
-        antwort=antwort.toLatin1()
+ 
 
-        if self.richtigeantwort==antwort:
+       
+    def antwort_1(self):  
+        antwort=self.ui.antwort_1.text()
+        antwort="%s" % unicode(antwort)
+        if self.antwort1==antwort:
             self.ui.textfrage.append("\nIhre Antwort ist richtig")
             self.score+=10
             self.richtigefragen+=1
@@ -262,7 +260,7 @@ class MainWindow(QtGui.QMainWindow):
             self.ui.antwort_4.hide()
             self.soundrichtig()
         else:
-            self.ui.textfrage.append("\nIhre Antwort ist falsch.\nDie richtige Anwort ist: "+self.richtigeantwort)
+            self.ui.textfrage.append("\nIhre Antwort ist falsch.\nDie richtige Anwort ist: "+self.antwort1)
             self.score-=10
             self.niederlagencounter+=1
             self.ui.punktestand.setText("Punktestand: "+str(self.score)+" Falsche Antworten: "+str(self.niederlagencounter))
@@ -274,13 +272,12 @@ class MainWindow(QtGui.QMainWindow):
             self.soundfalsch()   
                 
         self.status_check()
-                 
-             
+                     
     def antwort_2(self):
         antwort=self.ui.antwort_2.text()
-        antwort=antwort.toLatin1()
+        antwort="%s" % unicode(antwort)
 
-        if self.richtigeantwort==antwort:
+        if self.antwort1==antwort:
             self.ui.textfrage.append("\nIhre Antwort ist richtig")
             self.ui.nextquest.show()
             self.richtigefragen+=1
@@ -292,7 +289,7 @@ class MainWindow(QtGui.QMainWindow):
             self.ui.punktestand.setText("Punktestand: "+str(self.score)+" Falsche Antworten: "+str(self.niederlagencounter))
             self.soundrichtig()
         else:
-            self.ui.textfrage.append("\nIhre Antwort ist falsch.\nDie richtige Anwort ist: "+self.richtigeantwort)
+            self.ui.textfrage.append("\nIhre Antwort ist falsch.\nDie richtige Anwort ist: "+self.antwort1)
             self.ui.nextquest.show()
             self.niederlagencounter+=1
             self.score-=10
@@ -306,9 +303,9 @@ class MainWindow(QtGui.QMainWindow):
                    
     def antwort_3(self):
         antwort=self.ui.antwort_3.text()
-        antwort=antwort.toLatin1()
+        antwort="%s" % unicode(antwort)
 
-        if self.richtigeantwort==antwort:
+        if self.antwort1==antwort:
             self.ui.textfrage.append("\nIhre Antwort ist richtig")
             self.ui.nextquest.show()
             self.ui.antwort_1.hide()
@@ -321,7 +318,7 @@ class MainWindow(QtGui.QMainWindow):
             self.soundrichtig()
             
         else:
-            self.ui.textfrage.append("\n Ihre Antwort ist falsch.\nDie richtige Anwort ist: "+self.richtigeantwort)    
+            self.ui.textfrage.append("\n Ihre Antwort ist falsch.\nDie richtige Anwort ist: "+self.antwort1)    
             self.ui.nextquest.show()
             self.niederlagencounter+=1
             self.score-=10
@@ -334,9 +331,8 @@ class MainWindow(QtGui.QMainWindow):
         self.status_check()                                          
     def antwort_4(self):
         antwort=self.ui.antwort_4.text()
-        antwort=antwort.toLatin1()
-   
-        if self.richtigeantwort==antwort:
+        antwort="%s" % unicode(antwort)
+        if self.antwort1==antwort:
             self.ui.textfrage.append("\nIhre Antwort ist richtig")
             self.ui.nextquest.show()
             self.ui.antwort_1.hide()
@@ -348,7 +344,7 @@ class MainWindow(QtGui.QMainWindow):
             self.ui.punktestand.setText("Punktestand: "+str(self.score)+" Falsche Antworten: "+str(self.niederlagencounter))
             self.soundrichtig()
         else:
-            self.ui.textfrage.append("\nIhre Antwort ist falsch.\nDie richtige Anwort ist: "+self.richtigeantwort)     
+            self.ui.textfrage.append("\nIhre Antwort ist falsch.\nDie richtige Anwort ist: "+self.antwort1)     
             self.ui.nextquest.show()
             self.niederlagencounter+=1
             self.score-=10
